/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Directorys.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.mavenplugin.examples.directoryexploded;

import java.io.Serializable;
import java.util.List;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;

/**
 * Entity bean for table Directorys.
 * @author Julien Blais
 */
@Entity
@Table(name = "DIRECTORYS")
@NamedQueries({
@NamedQuery(name = "Directorys.findAll", query = "SELECT d FROM Directorys d"),
@NamedQuery(name = "Directorys.findByIddirectory", query = "SELECT d FROM Directorys d WHERE d.iddirectory = :iddirectory")})
public class Directorys implements Serializable {
    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = 29845987468978006L;
    /**
     * Id of directory.
     */
    @Id
    @Basic(optional = false)
    @Column(name = "IDDIRECTORY")
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Integer iddirectory;

    /**
     * Foreign key to get persons of the directory.
     */
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "iddirectory", fetch = FetchType.EAGER)
    private List<EltDirOf> eltDirOfCollection;

    /**
     * Foreign key references the user of the directory.
     */
    @JoinColumn(name = "USERNAME", referencedColumnName = "USERNAME")
    @OneToOne(optional = false, fetch = FetchType.EAGER)
    private Sessions idSession;

    /**
     * Empty conctructor.
     */
    public Directorys() {
    }

    /**
     * Gets the directory id.
     * @return the directory id
     */
    public Integer getIddirectory() {
        return iddirectory;
    }

    /**
     * Set the directory id.
     * @param iddirectory the new directory id
     */
    public void setIddirectory(final Integer iddirectory) {
        this.iddirectory = iddirectory;
    }

    /**
     * Gets the list of elements of the directory.
     * @return the list of elements referencing a person
     */
    public List<EltDirOf> getEltDirOfCollection() {
        return eltDirOfCollection;
    }

    /**
     * Gets the list of elements of the directory.
     * @param eltDirOfCollection the list
     */
    public void setEltDirOfCollection(final List<EltDirOf> eltDirOfCollection) {
        this.eltDirOfCollection = eltDirOfCollection;
    }

    /**
     * Get the directory owner name.
     * @return the owner name
     */
    public Sessions getIdSession() {
        return idSession;
    }

    /**
     * Set the directory owner name.
     * @param idSession the name
     */
    public void setIdSession(final Sessions idSession) {
        this.idSession = idSession;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (iddirectory != null) {
            hash += iddirectory.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        
        if (!(object instanceof Directorys)) {
            return false;
        }
        Directorys other = (Directorys) object;
        if ((this.iddirectory == null && other.iddirectory != null)
                || (this.iddirectory != null && !this.iddirectory.equals(other.iddirectory))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "Directorys[iddirectory=" + iddirectory + "]";
    }

}
